containertools.report_container_modifications
=============================================

.. autofunction:: abjad.tools.containertools.report_container_modifications.report_container_modifications
   :noindex:
